import axios from 'axios'
import queryString from 'query-string'
import { Message } from 'element-ui'
import router from '@/router'
import store from '@/store'

const httpRequest = axios.create({
  baseURL: import.meta.env.VITE_BASE_URL,
  timeout: 60000,
  withCredentials: true,
  headers: {
    'Content-Type': 'application/x-www-form-urlencoded'
  }
})

// 请求拦截
httpRequest.interceptors.request.use(
  function (config) {
    config.headers.tenant = store.state.appConfig.tenant
    if (/^\/api\/permissions/.test(config.url)) {
      // 默认参数
      const defaultHeaders = {
        timestamp: parseInt(Date.now() / 1000),
        nonce: Math.random().toString(36).slice(-8),
        'secret-id': import.meta.env.VITE_SECRET_ID,
        'secret-key': import.meta.env.VITE_SECRET_KEY,
        signature: 'UG7wBenexQhiuD2wpCwuxkU0jqcj006d'
      }
      config.headers = Object.assign(config.headers, defaultHeaders)
    }
    if (config.headers['Content-Type'] === 'application/x-www-form-urlencoded') {
      config.data = queryString.stringify(config.data)
    }
    if (config.headers['Content-Type'] === 'multipart/form-data') {
      const formData = new window.FormData()
      for (const key in config.data) {
        formData.append(key, config.data[key])
      }
      config.data = formData
    }
    return config
  },
  function (error) {
    return Promise.reject(error)
  }
)

// 响应拦截
httpRequest.interceptors.response.use(
  function (response) {
    const { data } = response
    // 正常返回
    if (data.code === 0) {
      return data
    }
    // 下载excel流
    if (data.type === 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet') {
      return data
    }
    // 获取阿里视频地址
    if (data.video) {
      return data
    }
    Message({ message: data.message || data.msg, type: 'error' })
    return Promise.reject(data)
  },
  function (error) {
    if (error.response) {
      const { status, message } = error.response.data
      if (status === 401 || status === 402) {
        router.replace('/401')
      }
      // 未登录
      if (status === 403) {
        window.location.href = `${import.meta.env.VITE_LOGIN_URL}?rd=${encodeURIComponent(window.location.href)}`
      } else {
        Message.error(message || error.response.data)
      }
      return Promise.reject(error.response)
    } else {
      console.log(error)
    }
    return Promise.reject(error)
  }
)

export default httpRequest
